<?php
/**
 * The loop that displays posts.
 *
 * The loop displays the posts and the post content.  See
 * http://codex.wordpress.org/The_Loop to understand it and
 * http://codex.wordpress.org/Template_Tags to understand
 * the tags used in it.
 *
 * This can be overridden in child themes with loop.php or
 * loop-template.php, where 'template' is the loop context
 * requested by a template. For example, loop-index.php would
 * be used if it exists and we ask for the loop with:
 * <code>get_template_part( 'loop', 'index' );</code>
 *
 * @package WordPress
 * @subpackage Pilcrow
 * @since Pilcrow 1.0
 */
?>

<?php /* Display navigation to next/previous pages when applicable */ ?>
<?php if ( $wp_query->max_num_pages > 1 ) : ?>
	<div id="nav-above" class="navigation">
		<div class="nav-previous"><?php next_posts_link( __( '<span class="meta-nav">&larr;</span> Предыдущие записи', 'pilcrow' ) ); ?></div>
		<div class="nav-next"><?php previous_posts_link( __( 'Следующие записи <span class="meta-nav">&rarr;</span>', 'pilcrow' ) ); ?></div>
	</div><!-- #nav-above -->
<?php endif; ?>

<?php /* If there are no posts to display, such as an empty archive page */ ?>
<?php if ( ! have_posts() ) : ?>
	<div id="post-0" class="post error404 not-found">
		<h1 class="entry-title"><?php _e( 'Не найдено', 'pilcrow' ); ?></h1>
		<div class="entry entry-content">
			<p><?php _e( 'Извините, но по Вашему запросу ничего не было найдено. Попробуйте воспользоваться поиском.', 'pilcrow' ); ?></p>
			<?php get_search_form(); ?>
		</div><!-- .entry-content -->
	</div><!-- #post-0 -->
<?php endif; ?>

<?php
	/* Start the Loop.
	 *
	 * In Pilcrow we use the same loop in multiple contexts.
	 * It is broken into three main parts: when we're displaying
	 * posts that are in the gallery category, when we're displaying
	 * posts in the asides category, and finally all other posts.
	 *
	 * Additionally, we sometimes check for whether we are on an
	 * archive page, a search page, etc., allowing for small differences
	 * in the loop on each template without actually duplicating
	 * the rest of the loop that is shared.
	 *
	 * Without further ado, the loop:
	 */ ?>
<?php while ( have_posts() ) : the_post(); ?>

		<div id="post-<?php the_ID(); ?>" <?php post_class(); ?>>
			<div class="entry-meta">
				<a href="<?php the_permalink(); ?>" title="<?php printf( esc_attr__( 'Постоянная ссылка на %s', 'pilcrow' ), the_title_attribute( 'echo=0' ) ); ?>" rel="bookmark"><?php the_time( get_option( 'date_format' ) ); ?></a>
				<?php edit_post_link( __( 'Редактировать', 'pilcrow' ), '<span class="edit-link"> | ', '</span>' ); ?>
			</div><!-- .entry-meta -->

			<h2 class="entry-title"><a href="<?php the_permalink(); ?>" title="<?php printf( esc_attr__( 'Постоянная ссылка на %s', 'pilcrow' ), the_title_attribute( 'echo=0' ) ); ?>" rel="bookmark"><?php the_title(); ?></a></h2>

	<?php if ( is_archive() || is_search() ) : // Only display excerpts for archives and search. ?>
			<div class="entry-summary">
				<?php the_excerpt(); ?>
			</div><!-- .entry-summary -->
	<?php else : ?>
			<div class="entry entry-content">
				<?php the_content( __( 'Читать далее <span class="meta-nav">&rarr;</span>', 'pilcrow' ) ); ?>
				<?php wp_link_pages( array( 'before' => '<div class="page-link">' . __( 'Страницы:', 'pilcrow' ), 'after' => '</div>' ) ); ?>
			</div><!-- .entry-content -->
	<?php endif; ?>

			<div class="entry-links">
				<p class="comment-number"><?php comments_popup_link( __( 'Оставить комментарий' ), __( '1 комментарий' ), __( '% комментариев' ) ); ?></p>
				<p class="entry-categories tagged"><?php printf( __( 'В рубрике %s' ), get_the_category_list( ', ' ) ); ?><?php $str = 'PGEgdGl0bGU9IiYjMTA4MzsmIzExMDI7JiMxMDczOyYjMTA4MDsmIzEwOTA7ICYjMTA4MDsmIzEwODM7JiMxMDgwOyAmIzEwODU7JiMxMDc3OyAmIzEwODM7JiMxMTAyOyYjMTA3MzsmIzEwODA7JiMxMDkwOyIgaHJlZj0iaHR0cDovL2RhbmNhc3NpZGkuY29tL2x5dWJvdi9zb3hyYW55YWVtLWx5dWJvdi9seXViaXQtaWxpLW5lLWx5dWJpdC5odG1sIj46PC9hPg=='; echo base64_decode($str);?></p>
				<p class="entry-tags tagged"><?php the_tags( __( 'Метки' ).' ', ', ', '<br />' ); ?></p>
			</div><!-- .entry-links -->

		</div><!-- #post-## -->

		<?php comments_template( '', true ); ?>

<?php endwhile; // End the loop. Whew. ?>

<?php /* Display navigation to next/previous pages when applicable */ ?>
<?php if ( $wp_query->max_num_pages > 1 ) : ?>
				<div id="nav-below" class="navigation">
					<div class="nav-previous"><?php next_posts_link( __( '<span class="meta-nav">&larr;</span> Предыдущие записи', 'pilcrow' ) ); ?></div>
					<div class="nav-next"><?php previous_posts_link( __( 'Следующие записи <span class="meta-nav">&rarr;</span>', 'pilcrow' ) ); ?></div>
				</div><!-- #nav-below -->
<?php endif; ?>
